import React from 'react'
import { translate } from 'cozy-ui/react/I18n'

import IFluidConfig from 'services/IFluidConfig'

import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import StyledButton from 'components/CommonKit/Button/StyledButton'
import TrailingIcon from 'assets/icons/ico/trailing-icon.svg'

interface KonnectorFormProps {
  fluidConfig: IFluidConfig
  login: string
  setLogin: Function
  password: string
  setPassword: Function
  loading: boolean
  error: string
  handleSubmit: Function
  t: Function
}

const KonnectorForm: React.FC<KonnectorFormProps> = ({
  fluidConfig,
  login,
  setLogin,
  password,
  setPassword,
  loading,
  error,
  handleSubmit,
  t,
}: KonnectorFormProps) => {
  const konnectorName: string = fluidConfig.konnectorConfig.name
  const konnectorType: string = fluidConfig.konnectorConfig.type

  function revealPassword(idInput: string) {
    const input = document.getElementById(idInput)
    if (input) {
      if (input.getAttribute('type') === 'password') {
        input.setAttribute('type', 'text')
      } else {
        input.setAttribute('type', 'password')
      }
    }
  }

  return (
    <form
      className="form"
      onSubmit={(e: React.FormEvent<HTMLFormElement>) => handleSubmit(e)}
    >
      {t('KONNECTORCONFIG.LABEL_FILLIN')} {konnectorName}
      <div className="form-group">
        <div className="form-message">{error}</div>
        <input
          id={'idFieldLogin' + konnectorType}
          type="text"
          className="form-control form-input"
          aria-describedby="emailHelp"
          placeholder="Adresse e-mail"
          name="login"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setLogin(e.target.value)
          }
          value={login}
        ></input>
      </div>
      <div className="form-group">
        <div className="form-message">{error}</div>
        <input
          id={'idFieldPassword' + konnectorType}
          type="password"
          className="form-control form-input"
          aria-describedby="PasswordHelp"
          placeholder="Mot de passe"
          name="password"
          onChange={(e: React.ChangeEvent<HTMLInputElement>) =>
            setPassword(e.target.value)
          }
          value={password}
        />
        <span>
          <StyledIconButton
            icon={TrailingIcon}
            className="form-trailing-icon"
            size={22}
            onClick={() => revealPassword('idFieldPassword' + konnectorType)}
          />
        </span>
      </div>
      <StyledButton type="submit" color="primary" disabled={loading}>
        {t('KONNECTORCONFIG.BTN_CONNECTION')}
      </StyledButton>
      <StyledButton type="button" color="secondary" disabled={loading}>
        {t('KONNECTORCONFIG.BTN_NOACCOUNT')}
      </StyledButton>
    </form>
  )
}

export default translate()(KonnectorForm)
